@@ -1,4 +1,4 @@
-__version__ = "2.0.6"
+__version__ = "3.0.0"
 
 from abc import ABC
 from pathlib import Path
@@ -9,12 +9,21 @@ from xsdata.formats.dataclass.parsers import XmlParser
 from xsdata.formats.dataclass.serializers import XmlSerializer
 
 
+class ParseError(Exception):
+    pass
+
+
+def is_history_file(path: Path):
+    content = open(path).read()
+    return "HistoryData" in content
+
+
 class TraktorNmlMixin(ABC):
     parser = XmlParser()
 
-    def __init__(self, path: Path, model):
+    def __init__(self, path, nml):
         self.path = path
-        self.nml: CollectionNml = model
+        self.nml = nml
 
     def save(self):
         with self.path.open(mode="w") as file_obj:
@@ -26,11 +35,17 @@ class TraktorNmlMixin(ABC):
 
 class TraktorCollection(TraktorNmlMixin):
     def __init__(self, path: Path):
-        nml = self.parser.from_path(path, CollectionNml)
-        super(TraktorCollection, self).__init__(path=path, model=nml)
+        if is_history_file(path):
+            raise ParseError(f"'{path}' is not a valid collection file")
+        self.path = path
+        self.nml: CollectionNml = self.parser.from_path(path, CollectionNml)
+        super().__init__(path=path, nml=self.nml)
 
 
 class TraktorHistory(TraktorNmlMixin):
     def __init__(self, path: Path):
-        nml = self.parser.from_path(path, HistoryNml)
-        super(TraktorHistory, self).__init__(path=path, model=nml)
+        if not is_history_file(path):
+            raise ParseError(f"'{path}' is not a valid history file")
+        self.path = path
+        self.nml: HistoryNml = self.parser.from_path(path, HistoryNml)
+        super().__init__(path=path, nml=self.nml)
